@@ -1,24 +1,13 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "shareserviceurlmanagertest.h"
 #include "../shareserviceurlmanager.h"
 #include <QTest>
-#include <kactionmenu.h>
+#include <KActionMenu>
 #include <QMenu>
 ShareServiceUrlManagerTest::ShareServiceUrlManagerTest(QObject *parent)
     : QObject(parent)
@@ -58,11 +47,6 @@ void ShareServiceUrlManagerTest::shouldGenerateServiceUrl_data()
     QTest::newRow("title and valid link (twitter)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::Twitter
                                                     << QUrl(QStringLiteral("https://twitter.com/share?url=http://www.kde.org&text=kde")) << true;
 
-    QTest::newRow("no title but valid link (googleplus)") << QString() << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::GooglePlus
-                                                          << QUrl(QStringLiteral("https://plus.google.com/share?url=http://www.kde.org")) << true;
-    QTest::newRow("title and valid link (googleplus)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::GooglePlus
-                                                       << QUrl(QStringLiteral("https://plus.google.com/share?url=http://www.kde.org")) << true;
-
     QTest::newRow("no title but valid link (mailto)") << QString() << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::MailTo
                                                       << QUrl(QStringLiteral("mailto:?subject&body=http://www.kde.org")) << true;
     QTest::newRow("title and valid link (mailto)") << QStringLiteral("kde") << QStringLiteral("http://www.kde.org") << PimCommon::ShareServiceUrlManager::MailTo
