@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templatelistwidget.h"
@@ -39,8 +27,7 @@ class TemplateListWidgetPrivate
 {
 public:
     TemplateListWidgetPrivate(const QString &configName, TemplateListWidget *qq)
-        : dirty(false)
-        , config(KSharedConfig::openConfig(configName, KConfig::NoGlobals))
+        : config(KSharedConfig::openConfig(configName, KConfig::NoGlobals))
         , q(qq)
     {
     }
@@ -52,7 +39,7 @@ public:
 
     void createListWidgetItem(const QString &name, const QString &text, bool isDefaultTemplate)
     {
-        QListWidgetItem *item = new QListWidgetItem(name, q);
+        auto *item = new QListWidgetItem(name, q);
         item->setData(TemplateListWidget::Text, text);
         item->setData(TemplateListWidget::DefaultTemplate, isDefaultTemplate);
         if (isDefaultTemplate) {
@@ -167,7 +154,7 @@ public:
     {
         const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
         const bool listSelectedIsEmpty = lstSelectedItems.isEmpty();
-        QMenu *menu = new QMenu(q);
+        auto *menu = new QMenu(q);
 
         if (!listSelectedIsEmpty) {
             menu->addAction(i18n("Insert template"), q, [this]() {
@@ -290,9 +277,9 @@ public:
     }
 
     QString knewstuffConfigName;
-    bool dirty;
+    bool dirty = false;
     KSharedConfig::Ptr config;
-    TemplateListWidget *q;
+    TemplateListWidget *const q;
 };
 
 TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *parent)
@@ -302,7 +289,7 @@ TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *paren
     setContextMenuPolicy(Qt::CustomContextMenu);
     setDragDropMode(QAbstractItemView::DragDrop);
 
-    connect(this, &TemplateListWidget::customContextMenuRequested, this, [this](const QPoint &p) {
+    connect(this, &TemplateListWidget::customContextMenuRequested, this, [this](QPoint p) {
             d->slotContextMenu(p);
         });
     connect(this, &TemplateListWidget::doubleClicked, this, [this]() {
@@ -341,7 +328,7 @@ QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> items) co
     if (items.isEmpty()) {
         return nullptr;
     }
-    QMimeData *mimeData = new QMimeData();
+    auto *mimeData = new QMimeData();
     QListWidgetItem *item = items.first();
     mimeData->setText(item->data(TemplateListWidget::Text).toString());
     return mimeData;
