@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CHECKEDCOLLECTIONWIDGET_H
@@ -32,6 +21,10 @@ class Collection;
 
 namespace PimCommon {
 class CheckedCollectionWidgetPrivate;
+/**
+ * @brief The CheckedCollectionWidget class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMONAKONADI_EXPORT CheckedCollectionWidget : public QWidget
 {
     Q_OBJECT
