@@ -1,26 +1,12 @@
 /*
-   Copyright 2010 Thomas McGuire <mcguire@kde.org>
-   Copyright 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "annotationdialog.h"
-#include "kpimtextedit/plaintexteditorwidget.h"
+#include <KPIMTextEdit/PlainTextEditorWidget>
 
 #include <KMessageBox>
 #include <KLocalizedString>
@@ -63,7 +49,7 @@ AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *p
     d->mHasAnnotation = item.hasAttribute<Akonadi::EntityAnnotationsAttribute>();
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -73,7 +59,7 @@ AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *p
 
     if (d->mHasAnnotation) {
         setWindowTitle(i18nc("@title:window", "Edit Note"));
-        QPushButton *user1Button = new QPushButton;
+        auto *user1Button = new QPushButton;
         buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
         user1Button->setText(i18nc("@action:button", "Delete Note"));
         user1Button->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
@@ -85,14 +71,14 @@ AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *p
     buttonBox->button(QDialogButtonBox::Ok)->setDefault(true);
 
     QLabel *label = new QLabel(i18n("Enter the text that should be stored as a note to the mail:"));
-    QVBoxLayout *vbox = new QVBoxLayout(mainWidget);
+    auto *vbox = new QVBoxLayout(mainWidget);
     vbox->setContentsMargins(0, 0, 0, 0);
     d->mTextEdit = new KPIMTextEdit::PlainTextEditorWidget(this);
     vbox->addWidget(label);
     vbox->addWidget(d->mTextEdit);
     d->mTextEdit->setFocus();
 
-    QHBoxLayout *hbox = new QHBoxLayout;
+    auto *hbox = new QHBoxLayout;
     hbox->addStretch();
     label = new QLabel(i18nc("@label:listbox", "Note type:"));
     hbox->addWidget(label);
@@ -126,7 +112,7 @@ void AnnotationEditDialog::slotAccepted()
     bool textIsEmpty = d->mTextEdit->isEmpty();
     if (!textIsEmpty) {
         d->mItem.removeAttribute<Akonadi::EntityAnnotationsAttribute>();
-        Akonadi::EntityAnnotationsAttribute *annotation = d->mItem.attribute<Akonadi::EntityAnnotationsAttribute>(Akonadi::Item::AddIfMissing);
+        auto *annotation = d->mItem.attribute<Akonadi::EntityAnnotationsAttribute>(Akonadi::Item::AddIfMissing);
         QMap<QByteArray, QByteArray> map;
         map.insert(d->mNoteType->itemData(d->mNoteType->currentIndex()).toByteArray(), d->mTextEdit->toPlainText().toUtf8());
         annotation->setAnnotations(map);
